var parser = require('./')
var parse = parser('--foo "-bar"')
console.log(parse)
